# CHANGELOG

This is a manually generated log to track changes to the repository for each release. 
Each section should include general headers such as **Implemented enhancements** 
and **Merged pull requests**. 

The versions coincide with releases on pypi.

## [0.0.x](https://github.com/vsoch/juliart/tree/master) (0.0.x)
 - bug that default alpha should be 100 (not 1) (0.0.15)
 - automated builds to quay.io and word wrap for longer text (0.0.14)
 - adding control for ca and cb parameters (0.0.13)
 - JuliaSetAnimation class to generation animations (0.0.12)
 - adding color themes (0.0.11)
 - initial release with basic generation for random, glow, pattern colors (0.0.1)

